@echo off
setlocal enableextensions enabledelayedexpansion

:CHECKHELP

	(echo.%*|findstr /L /i /c:"/help" /c:"/h" /c:"/?" >nul: 2>&1) && (goto :HELP)
	echo.
	goto :SETUP %*

:CHECKHELP_END

	
:SETUP
	if "%~2" equ "" goto :HELP
	
	call "%~dp0AutoCams.setup.bat" "%~dpnx0"
	call "%~dp0indent_setup.bat"

	call "!bat_exedir!\ReadParams.bat"

	!bat_log!
	!bat_log! =============================================================
	!bat_log! %date% %time% - Version: !bat_vers! - %~dpnx0 [%*]
	!bat_log! [!bat_batchfile!:SETUP %*]  Please wait...
	!bat_pushlog!

		rem Get the bat_capturedfilesdir value
	call :READCONFIG

	set bat_capturedfilesdir=%~1
	set bat_captureddatedir_name=%~n1
	set bat_captureddate=!bat_captureddatedir_name:~0,10!
	set bat_capturedtime=!bat_captureddatedir_name:~-8!

		rem Format the capture session in a format similar to how the FF and CAL files are timestamped.  
	set bat_capture_session=!bat_captureddate:~0,4!!bat_captureddate:~5,1!!bat_captureddate:~-2!_!bat_capturedtime:~0,2!!bat_capturedtime:~3,2!!bat_capturedtime:~-2!

	
	set bat_detectfile_full=%~2
	set bat_detectfile=%~nx2
	set bat_detectfile_filename=%~nx2
	set bat_detectfile_name=%~n2

	set bat_detect_dir=%~dp2::
	if /i "!bat_detect_dir!" equ "::" (
		!bat_echolog!
		!bat_echolog! `    ERROR - Must specify the full path.
		set bat_returncode=3
		goto :DONE
	)
	
	set bat_detect_dir=!bat_detect_dir:\::=!
	set bat_detect_dir=!bat_detect_dir:::=!
	
	if /i "!bat_detect_dir:~1,1!" neq ":" (
		!bat_echolog!
		!bat_echolog! `    Invalid path ["!bat_detectfile_full!"]
		set bat_returncode=2
		goto :DONE
	)
	
	set bat_targetdrive=!bat_detect_dir:~0,2!

	if /i "!bat_detectfile_filename:~-4!" neq ".txt" (
		!bat_echolog!
		!bat_echolog! `    ERROR - Must specify a detect file, not just the path.
		set bat_returncode=3
		goto :DONE
	
	)
	
	set bat_autonomous=
	if /i "%~3" equ "autonomous" (
		set bat_autonomous="autonomous"
	)


	set bat_cameralist_file=!bat_detect_dir!\SortDetect_CameraList.txt
	
	
	set bat_calfilelist_name=!bat_detect_dir!\CalFileList
	set bat_calfilelist_filename=!bat_calfilelist_name!_temp.txt
	

goto :MAIN %*






	rem *************************************************************
	rem ****                      MAIN                           ****
	rem 
	rem The purpose is to provide a stand-alone utility to display
	rem and return whether the specified detect file has all its
	rem cameras calibrated.
	rem 
	rem 
	rem 
	
:MAIN
!bat_pushlog! [!bat_batchfile!:MAIN] [%*]

	!bat_logexeclog! move /y "!bat_calfilelist_name!.log" "!bat_calfilelist_name!.log.bak"
	
		rem Generates CalFileList.log [if it's not there]
	!bat_CALL! "!bat_exedir!\CreateCalFileList.bat" "!bat_detectfile_full!"
	
		rem Renames "CalFileList.log" to "CalFileList_temp.log"
	!bat_logexeclog! move /y "!bat_calfilelist_name!.log"  "!bat_calfilelist_name!_temp.log"


	if not defined bat_FFfirst (
			rem Gets bat_FFfirst, bat_FFlast, 
		!bat_CALL! "!bat_exedir!\GetFirstLastFF_filenames.bat" "bat_FFfirst"    "bat_FFlast"   "!bat_capturedfilesdir!"
	)

	if not exist "!bat_cameralist_file!" (
			rem Creates bat_camera, bat_camera_list, and creates the SortDetect_CameraList.txt file. 
		!bat_CALL! "!bat_exedir!\CreateCameraListFileFromDetectFile.bat" "!bat_detectfile_full!"
	)

	set bat_first_timestamp=!bat_FFfirst:~6,15!
	set bat_last_timestamp=!bat_FFlast:~6,15!
	

	!bat_echolog!
	!bat_echolog! ` Temporary Detect File [notice the "C" suffix]:
	!bat_echolog! `     "!bat_detectfile_full!"
	!bat_echolog!   
	!bat_echolog! `  The FF file and the CAL files should have matching dates
	!bat_echolog! `  with possibly different times.  The time of the cal file
	!bat_echolog! `  should match the time of the FF file chosen for 
	!bat_echolog! `  calibration ^(that you wrote down^).
	!bat_echolog!
	!bat_echolog! `  This routine should have applied your latest calibration 
	!bat_echolog! `  file with the matching date/time in the listed cal filename.
	!bat_echolog!
	!bat_echolog! `  The timestamps should indicate that they fall within the capture session
	!bat_echolog! `  first/last files, otherwise, the cal is from a different capture session.
	!bat_echolog!



		rem bat_returncode will be 21 if there is a date mismatch with an FF file and 22 
		rem for a date mismatch with 
	call :CHECK_APPLY_C "!bat_detectfile_full!"

	
	!bat_logexeclog! move /y "!bat_calfilelist_name!.log.bak"   "!bat_calfilelist_name!.log"
	!bat_logexeclog! del /q "!bat_calfilelist_name!_temp.log"


	
:MAIN_END
!bat_poplog! [END-!bat_batchfile!:MAIN] - goto :DONE
goto :DONE





	rem *************************************************************
	rem ****               CHECK_APPLY_C                         ****
	rem 
	rem Scans and lists the last the FF files and its cal file for
	rem each camera.
	rem 
	rem Parameters:
	rem     %~1					The bat_detectfile_full to scan
	rem 
	rem *************************************************************

:CHECK_APPLY_C [IN] "!bat_detectfile_full!"
!bat_pushlog! [CALL !bat_batchfile!:CHECK_APPLY_C] [%*]

	set bat_returncode=0

		rem !bat_detect_dir!\SortDetect_CameraList.txt
	!bat_pushlog! for /f "usebackq tokens=*" ..c in ^(`type "!bat_cameralist_file!"`^) do ^(
	              for /f "usebackq tokens=*" %%c in  (`type "!bat_cameralist_file!"`) do (

			rem For each camera...	
		set bat_ffname=
		set bat_calname=
		set bat_camera_temp=
		!bat_pushlog! for /f "usebackq tokens=*" ..a in ^(`findstr /i /c:"CAL%%c_" "!bat_calfilelist_name!_temp.log"`^) do...
		for               /f "usebackq tokens=*" %%a in  (`findstr /i /c:"CAL%%c_" "!bat_calfilelist_name!_temp.log"`) do (
			!bat_logexeclog! set bat_temp=%%a


			if /i "!bat_temp:~0,7!" equ "CAL%%c_" (

				if not defined bat_calname (

					!bat_logexeclog! set bat_calname=!bat_temp!

					!bat_logexeclog! set bat_cal_datetime=!bat_temp:~7,15!
					
					set bat_match=true
					if "!bat_cal_datetime!" LSS "!bat_first_timestamp!" (set bat_match=)
					if "!bat_cal_datetime!" GTR "!bat_last_timestamp!"  (set bat_match=)
					
					if defined bat_match (
						set bat_match_string=	**** MATCH                     ****  
					) else (
						set bat_match_string=   **** MISMATCH Needs manual cal ****  
						set bat_returncode=22
					)


					!bat_CALL! "!bat_exedir!\GetFirstLastFF_filenames.bat" "bat_FFfirst"    "bat_FFlast"   "!bat_capturedfilesdir!" "%%c"

					!bat_echolog! `  !bat_FFfirst!  - First FF file in capture session
					!bat_echolog! `  !bat_FFlast!  - Last  FF file in capture session
					!bat_echolog!

					!bat_echolog! ` !bat_temp!	- !bat_match_string! The first CAL file for camera !bat_camera_temp! in the detect file after applying 
					!bat_echolog!
				)
			)
		)
		!bat_poplog! ^) // bat_camera=[%%c], bat_ffname=[!bat_ffname!]



		if defined bat_calname (
			rem !bat_echolog! !bat_calname!      [The current CAL file in the detect file after applying]
		) else (
			!bat_echolog! `    ERROR 24 - Could not find ".txt" files in "!bat_detectfile_full!
			!bat_echolog! `              Check the camera number
			set bat_returncode=24
			!bat_log! `    set bat_returncode=!bat_returncode!
			goto :APPLY5
		)
	)
	!bat_poplog! ^) // bat_ffname=[!bat_ffname!]

	
:CHECK_APPLY_C_END
!bat_poplog! [RETURN !bat_batchfile!:CHECK_APPLY_C] []
!bat_log!
!bat_return!






rem *************************************************************
rem ***** This should be made into a standalone batch file ******
rem *************************************************************
:APPLYBEGIN
!bat_pushlog! [CALL !bat_batchfile!:APPLYBEGIN] %*


:APPLY1
!bat_log! [!bat_batchfile!:APPLY1]

	set bat_returncode=0

	!bat_echolog!
	!bat_echolog!     This step runs FTP_ApplyCal2Detectinfo.exe
	!bat_echolog!

	if not defined bat_autonomous (
		!bat_echolog! You may be given the following instruction due to a confusing typo in the .exe program:
		!bat_echolog! Navigate to FTP Detection File to Process for Coincidence'.  Instead, it means:
		!bat_echolog! Navigate to FTP Detection file to Process for Apply".
		!bat_echolog!
		!bat_echolog! Instead, navigate to and select:
		!bat_echolog!     "!bat_detectfile1!".
		
		if /i exist "!bat_detectfile1!" (
			!bat_echolog!
			!bat_echolog! Note: The current CAL files found in the detect file [!bat_detectfile1!]
			!bat_echolog! `     that should match the Cal Date:
			!bat_pushecho! `       "!bat_caldate!" are:
				!bat_echolog!
				set /a bat_count_match=0
				set /a bat_count=0
				set /a bat_count_mismatch=0
				for /f "usebackq tokens=*" %%a in (`type "!bat_detect_dir!\CalFileList.log"`) do (
					set /a bat_count+=1
					
					set bat_cal_temp=%%a
					set bat_cal_temp_dirdate=!bat_cal_temp:~7,8!
					
					if /i "!bat_cal_temp_dirdate!" equ "!bat_caldate!" (
						set /a bat_count_match+=1
						!bat_echolog! %%a		MATCH
					) else (
						set /a bat_count_mismatch+=1
						!bat_echolog! %%a		**** MISMATCH - Needs Apply ****
					)
				)
			!bat_popecho!
		)

		set bat_choice=
		!bat_prompt! Use this and [A]pply the cal, [S]kip, or [Q]uit : 
		
		if /i "!bat_choice!" equ "q" (
			set bat_returncode=9
			!bat_log! `    set bat_returncode=!bat_returncode!
			goto :APPLY5
		)
		
		if /i "!bat_choice!" equ "s" (
			!bat_log! for /f "usebackq tokens=* skip=2" ..a in ^(`find /i ".txt" "!bat_detectfile1!"`^) do...
			for           /f "usebackq tokens=* skip=2" %%a in  (`find /i ".txt" "!bat_detectfile1!"`) do (
				set bat_temp=%%a
				if "!bat_temp:~3,3!" equ "!bat_camera!" (
					set bat_calname=%%a
				)
			)

			goto :APPLY4
		)

		if /i "!bat_choice!" neq "a" goto :APPLY1
	)

	find /i ".bin" "!bat_detectfile1!">nul:
	if !errorlevel! neq 0 (
		!bat_echolog! `    ERROR 20 - No events found in "!bat_detectfile1!"
		set bat_returncode=20
		!bat_log! `    set bat_returncode=!bat_returncode!
		goto :APPLY5
	)

	!bat_echolog! *************************************************************
	!bat_echolog! call "!bat_exedir!\FTP_ApplyCal2Detectinfo.exe" "!bat_detectfile1!"{CRLF.inp
	              call "!bat_exedir!\FTP_ApplyCal2Detectinfo.exe" "!bat_detectfile1!"<CRLF.inp
	set bat_returncode=!errorlevel!
	!bat_echolog! Back from  call "!bat_exedir!\FTP_ApplyCal2Detectinfo.exe" "!bat_detectfile1!"
	!bat_echolog! [bat_returncode=!bat_returncode!]
	!bat_echolog! *************************************************************
	
	if "!bat_returncode!" neq "0" (
		!bat_echolog!
		!bat_echolog! `    ERROR !bat_returncode! - Aborting - Program returned with the error code
		!bat_echolog!
		goto :APPLY5
	)
	

	!bat_echolog!
	!bat_pushecho! Now checking validity of the outcome...

		rem We check the validity by:
		rem   1. Fetch the first FF file in the detect file
		rem   2. Fetch the first Cal file in the detect file
		
		!bat_echolog!
		!bat_echolog!
		!bat_echolog!   The FF file and the CAL files should have matching dates
		!bat_echolog!   with possibly different times.  The time of the cal file
		!bat_echolog!   should match the time of the FF file chosen for 
		!bat_echolog!   calibration ^(that you wrote down^).
		!bat_echolog!
		!bat_echolog!   This routine should have applied your latest calibration 
		!bat_echolog!   file with the matching date/time in the listed cal filename.
		!bat_echolog!
		!bat_echolog!   The timestamps should indicate that they fall within the capture session
		!bat_echolog!   first/last files, otherwise, the cal is from a different capture session.
		!bat_echolog!
		!bat_echolog! First FF file in capture session: "!bat_FFfirst!"
		!bat_echolog! Last  FF file in capture session: "!bat_FFlast!"
		!bat_echolog!

		if not defined bat_FFfirst (
			!bat_logexeclog! call "!bat_exedir!\GetFirstLastFF_filenames.bat" "bat_FFfirst"    "bat_FFlast"   "!bat_capturedfilesdir!"
		)
		
		set bat_first_timestamp=!bat_FFfirst:~6,15!
		set bat_last_timestamp=!bat_FFlast:~6,15!

			rem bat_returncode will be 21 if there is a date mismatch with an FF file and 22 
			rem for a date mismatch with 
		call :CHECK_APPLY_C "!bat_detect_dir!\!bat_detectfile3!C.txt"
		


	!bat_pop!

	
	!bat_echolog!
	if not defined bat_autonomous (
		set bat_choice=
		set /p bat_choice=.!bat_pushstring!If this is correct, enter [C]ontinue, [R]eject and try again, or [Q]uit : 
		if /i "!bat_choice!" equ "c" goto :APPLYEND
		if /i "!bat_choice!" equ "r" goto :APPLYBEGIN
		if /i "!bat_choice!" equ "q" (
			set bat_returncode=1
			!bat_log! `    set bat_returncode=!bat_returncode!
			goto :APPLY5
		)
	) else (
		goto :APPLYEND
	)

:APPLYEND	
!bat_log! [!bat_batchfile!:APPLYEND]

	!bat_logexec! move /y "!bat_detect_dir!\!bat_detectfile3!C.txt" "!bat_detectfile1!"

:APPLY4
!bat_log! [!bat_batchfile!:APPLY4]
	if exist "!bat_detect_dir!\!bat_detectfile3!C.txt" (
		set bat_returncode=1
		!bat_echolog! `     ERROR - The {apply} file wasn't able to be moved to the detect file
		!bat_echolog! `     "!bat_detect_dir!\!bat_detectfile3!C.txt"
		
		if defined bat_autonomous (
			goto :APPLY5
		) else (
			set /p bat_choice=  [C]ontinue, [R]etry, or [Q]uit?  
			if /i "!bat_choice!" equ "c" goto :APPLY5
			if /i "!bat_choice!" equ "r" goto :APPLYBEGIN
			if /i "!bat_choice!" equ "q" (
				set bat_returncode=1
				!bat_log! `    set bat_returncode=!bat_returncode!
				goto :APPLY5
			)
			goto :APPLY4
		)
	) else (
		!bat_echolog! `    Move was successful and there is only one detect file. Now checking if the cal file is in the detect file...

		find /i /c "!bat_calname!" "!bat_detectfile1!">nul:
		if "!errorlevel!" equ "0" (
			!bat_echolog!
			!bat_echolog!   SUCCESS - '!bat_calname!' was applied to '!bat_detectfile1!'
			!bat_echolog!
			set bat_returncode=0
			!bat_log! `    set bat_returncode=!bat_returncode!
		) else (
			!bat_echolog!
			!bat_echolog!   ERROR - '!bat_calname!' was NOT applied to '!bat_detectfile1!'
			!bat_echolog!
			set bat_returncode=1
			!bat_log! `    set bat_returncode=!bat_returncode!
			goto :APPLY5
		)
	)

:APPLY5
!bat_poplog! [RETURN !bat_batchfile!:APPLYBEGIN] [bat_returncocde=!bat_returncode!]
!bat_log!
!bat_return!





:GETDETECTFILE
!bat_pushlog! [CALL !bat_batchfile!:GETDETECTFILE] %*

	set bat_returncode=0
	set bat_detectfile_temp=

	call "!bat_exedir!\GetDetectFile.bat" "bat_detectfile" "!bat_detect_dir!"
	
	set bat_returncode=!errorlevel!
	if "!bat_returncode!" neq "0" (
			!bat_echolog! `     ERROR - GetDetectFile.bat - Returned error code "!bat_returncode!"
			!bat_echolog! `             bat_detectfile="!bat_detectfile!"
		goto :GETDETECTFILE_END
	)

	if not exist "!bat_detectfile!" (
			set bat_returncode=2
			!bat_echolog! `     Not found: "!bat_detect_dir!\FTPdetectinfo_0*.txt"
			goto :GETDETECTFILE_END
	)

		rem Parse the bat_detectfile full name into parts...
	for /f "usebackq tokens=*" %%a in (`dir "!bat_detectfile!" /a-d /b /od`) do (
		set bat_detectfile_temp=!bat_detect_dir!\%%~nxa
		set bat_detectfile1=!bat_detect_dir!\%%~nxa
		set bat_detectfile2=%%~nxa
		set bat_detectfile3=%%~na
	)

	if not defined bat_detectfile_temp (
		set bat_returncode=2
		!bat_echolog! `     Not found: "!bat_detect_dir!\FTPdetectinfo_0*.txt"
		goto :GETDETECTFILE_END
	)


	
	!bat_logexeclog! set bat_GCFC_tempfile=!bat_capturedfilesdir!\GCFC.log

	call "!bat_exedir!\GetCameraList.bat" "!bat_capturedfilesdir!"
	set bat_returncode=0

:GETDETECTFILE_END
!bat_poplog! [RETURN !bat_batchfile!:GETDETECTFILE] [bat_returncode=!bat_returncode!, 
!bat_log! `                                        bat_camera=!bat_camera!, 
!bat_log! `                                        bat_camera_list=!bat_camera_list!, 
!bat_log! `                                        bat_detectfile=!bat_detectfile!]
!bat_log!
!bat_return!




	rem Checks to see if the camera in arg1 exists in the GCFC.log file
	rem Returns: bat_GCFC_found=true if the camera is found
:CHECK_GCFC
rem !bat_pushlog! [CALL !bat_batchfile!:CHECK_GCFC] [%*]
	set bat_GCFC_found=
	for /f "usebackq tokens=*" %%x in (`type "!bat_GCFC_tempfile!"`) do (
		if /i "%~1" equ "%%~x" (
			set bat_GCFC_found=true
		)
	)
:CHECK_GCFC_END
rem !bat_poplog! [RETURN !bat_batchfile!:CHECK_GCFC] [%~1, bat_GCFC_found=!bat_GCFC_found!]
!bat_return!




:GETCAMERALIST
!bat_pushlog! [CALL !bat_batchfile!:GETCAMERALIST] %*

	set bat_camera_list=
	for /f "usebackq tokens=*" %%a in (`type "!bat_GCFC_tempfile!"`) do (
		if not defined bat_camera_list (
			set bat_camera_list=0!%%a
		) else (
			set bat_camera_list=!bat_camera_list!0%%a
		)
	)

:GETCAMERALIST_END
!bat_poplog! [RETURN !bat_batchfile!:GETCAMERALIST] [bat_cameralist=!bat_cameralist!]
!bat_log!
!bat_return!










:READCONFIG
!bat_pushlog! [CALL !bat_batchfile!:READCONFIG] %*

	!bat_logexeclog! call "!bat_exedir!\ReadConfig.bat" 

:READCONFIG_END
!bat_poplog! [RETURN !bat_batchfile!:READCONFIG] [bat_capturedfilesdir=!bat_capturedfilesdir!]
!bat_log!
!bat_return!










:HELP
	echo %~0      Batch Script
	echo.
	echo.    Usage %~0 ^<captured files dir^> ^<detect file^>
	echo.
	echo.    Example: 
	echo.       CALL "GetApplyCalStatus.bat" "d:\cams16\CAMS\CapturedFiles\2014_12_23_01_53_58" "d:\cams16\CAMS\ArchivedFiles\2014_12_23_01_53_58\FTPdetectinfo_02500256_2014_12_23_01_53_58.txt"
	echo.
	echo.    The detect file must be a fully qualified detect file name. 
	echo.
	echo.   The bat_capturedfilesdir value is obtained by reading Autocams.bat.ini file. 
	echo.
	echo.    The script was designed to perform the following tasks:
	echo.      1.  Display the calibration status of each camera found in the detect file.  
	echo.          The timestamps should indicate that they fall within the capture session
	echo.          first/last files, otherwise, the cal is from a different capture session.
	echo.   
	echo.    		FF258_20141223_015401_074_0000000.bin  - First FF file in capture session
	echo.    		FF258_20141223_143706_376_1372160.bin  - Last  FF file in capture session
	echo.
	echo.    		CAL258_20141214_111841_134.txt         - **** MISMATCH Needs manual cal ****   The first CAL file for camera  in the detect file after applying
	echo.   
	echo.    		FF259_20141223_015402_019_0000000.bin  - First FF file in capture session
	echo.    		FF259_20141223_143707_485_1372160.bin  - Last  FF file in capture session
	echo.   
	echo.    		CAL259_20141214_095542_102.txt         - **** MISMATCH Needs manual cal ****   The first CAL file for camera  in the detect file after applying
	echo.   
	echo.    		FF260_20141223_015402_956_0000000.bin  - First FF file in capture session
	echo.    		FF260_20141223_143708_151_1372160.bin  - Last  FF file in capture session
	echo.
	echo.           CAL260_20141214_095443_206.txt           -    **** MISMATCH Needs manual cal ****   The first CAL file for camera  in the detect file after applying
	echo.
	echo.     2. help the user to decide how to handle mismatched calibrations. 
	echo.
exit /b



:DONE
	!bat_poplog! [goto !bat_batchfile!:DONE] [bat_returncode=!bat_returncode!]
	!bat_log! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!bat_log! exit /b !bat_returncode!
          exit /b !bat_returncode!
