

	REM ******************************************************************
	REM RedirectLogs.bat                                    **************
	REM                                                     **************
	REM This script redirects the logs to a new location, adjusts the
	REM variables, and reconfigures the bat_logdir variables for use with
	REM the bat_log, bat_echolog, etc. macros.  
	REM
	REM This script makes it possible to keep the log files encapsulated
	REM with the capture session that was running at the time [or the
	REM post capture scripts that were run for it].
	REM
	REM One of the challenges is that when first start a program, such as
	REM LaunchCapture.bat or AutoCams.bat, there is no capture session
	REM for it to use.  Therefore, the default location to store the log files
	REM is "C:\CAMS\Logs".  Once a capture session [bat_captureddate_bat_capturedtime]
	REM is established, the logs are store in a subdir denoted by the 
	REM capture session.  For example, "C:\CAMS\Logs\2014_12_13_01_39_13".
	REM this script can be called to migrate the existing
	REM log files to that directory.  If there are already files in that
	REM directory, then this script will merge the ones from "C:\CAMS\Logs"
	REM with the ones already in the target directory.  It is assumed [from
	REM experience with autocams] that the C:\CAMS\Logs directory is the newer
	REM collection of logs, therefore, they are appended to the ones in the 
	REM target dir.  
	REM 
	REM Since we have the concept of the SubmissionFiles directory, and we
	REM move the files away from the four working directories, when we
	REM run option "13. StageFromConfirmed.bat", the files related to the
	REM capture session are MOVED to under SubmissionFiles.  The Log
	REM files are also moved and migrated also.  That way, when we archive
	REM these session, we can go back and examine if t here was something
	REM we need to address without having to download all the files and re-work
	REM them with possibly newer/incompatible software. 
	REM
	REM Finally, if the autocams "15. Move SubmissionFiles dirs to working dirs" 
	REM is used to move a captured session from the SubmissionFiles area
	REM back to the working directories area, the log files are restored to
	REM C:\CAMS\Logs\[date_time]
	REM 
	REM One issue with this script is how much to display.  Since the 
	REM log directories are in flux during this time, we can't really safely
	REM write to them.  Therefore, the !bat_echo! macro was used instead
	REM of bat_logexeclog and so on.  We need to come up with a better method
	REM for this.  One though that came to mind was simply launching it
	REM in its default verbose mode, but launch it to an asynchronous process
	REM and then wait for it.  The asynchronous process would run in a minimized
	REM window in the background until it's done.  At which point, the main
	REM window awakens and continues processing.
	REM
	REM ******************************************************************

:CHECKHELP
    echo.%*|find /i "/?">nul:
    if %errorlevel% equ 0 goto :HELP
    echo.%*|find /i "/h">nul:
    if %errorlevel% equ 0 goto :HELP
    echo.%*|find /i "/help">nul:
    if %errorlevel% equ 0 goto :HELP


	set bat_pushstring_save=!bat_pushstring!

	set bat_batchfile_save=!bat_batchfile!
	set bat_batchfile=%~nx0
	set bat_logfile_name_save=!bat_logfile_name!
	set bat_logfile_name=!bat_batchfile!.log

	goto :DONE

	
	if /i "%~2" equ "" (
		if /i "%~1" NEQ "" (

			!bat_log!
				rem Just setting the logdir and other vars without migrating and merging.
			set bat_logdir=%~1
			set bat_logfile=!bat_logdir!\!bat_logfile_name!
			set bat_logfile_full=!bat_logdir!\AutoCams_full.log
			
			if not exist "!bat_logdir!" (
				!bat_logexeclog! MD "!bat_logdir!"
				!bat_log! bat_logexec_returncode=!bat_logexec_returncode!
			)

			!bat_log! =============================================================
			!bat_log! [%date% %time%] - Version: !bat_vers! - %~dpnx0 [%*]
			!bat_log! [%~dpnx0:SETUP %*]  Please wait...
			!bat_pushlog!

			!bat_log!
			!bat_log! After redirecting, the Current bat_logdir=!bat_logdir!
			!bat_log! After redirecting, the Current bat_logfile=!bat_logfile!
			!bat_log! After redirecting, the Current bat_logfile_full=!bat_logfile_full!


			!bat_echolog! `    !bat_batchfile!:CHECKHELP - OK - Just setting the bat_logdir without migrating and merging
			goto :DONE
		) else (
			!bat_echolog!
			!bat_echolog! `    %~nx0:SETUP - ERROR - Log missing source and dest directory command line options. 
			!bat_echolog!
			goto :HELP
		)
	)
	
	
	
	
	
	
	
	
	if /i "%~2" equ "!bat_logdir!" (
		!bat_log! =============================================================
		!bat_log! [%date% %time%] - Version: !bat_vers! - %~dpnx0 [%*]
		!bat_log! [%~dpnx0:SETUP %*]  Please wait...
		!bat_pushlog!
		
		!bat_log! `    !bat_batchfile!:CHECKHELP - OKDestination dir same as source dir.  Aborting
		goto :DONE
	)

:CHECKHELP_END


:NORMALIZE_VARIABLES

	rem Always need bat_logdir, bat_logfile, bat_logfile_name, bat_logfile_full
	
	set bat_redirect_base=%~dp0Logs
	
	if not defined bat_logdir (
		set bat_logdir=!bat_redirect_base!
	)

	set bat_logfile=!bat_logdir!\!bat_logfile_name!
	set bat_logfile_full=!bat_logdir!\AutoCams_full.log

:NORMALIZE_VARIABLES_END

:SETUP
	!bat_log!
	!bat_log! =============================================================
	!bat_log! [%date% %time%] - Version: !bat_vers! - %~dpnx0 [%*]
	!bat_log! [%~dpnx0:SETUP %*]  Please wait...
	!bat_pushlog!

echo.[!date! !time!] %~nx0 [%*]>>"C:\%~nx0.log"


	!bat_log! Before redirecting, the Current bat_logdir=!bat_logdir!
	!bat_log! Before redirecting, the Current bat_logfile=!bat_logfile!
	!bat_log! Before redirecting, the Current bat_logfile_full=!bat_logfile_full!
		
	!bat_logexeclog! set bat_redirect_base
	!bat_logexeclog! set bat_redirect_currentdir=!bat_logdir!
	!bat_logexeclog! set bat_redirect_sourcedir=%~1
	!bat_logexeclog! set bat_redirect_destdir=%~2
		
	!bat_logexeclog! MD "!bat_redirect_sourcedir!"
	!bat_logexeclog! MD "!bat_redirect_destdir!"

	echo.!bat_redirect_sourcedir!|find /i "\\" 
	if !errorlevel! equ 0 (
		
		!bat_echolog! EXITING RedirectLogs.bat EARLY - invalid source path...[!bat_redirect_sourcedir!]
		goto :DONE
	)

	if /i "!bat_redirect_sourcedir:~-1,1!" equ "\" (
		
		!bat_echolog! EXITING RedirectLogs.bat EARLY - invalid source path...[!bat_redirect_sourcedir!]
		goto :DONE
	)

	echo.!bat_redirect_destdir!|find /i "\\"
	if !errorlevel! equ 0 (
		
		!bat_echolog! EXITING RedirectLogs.bat EARLY - invalid dest path...[!bat_redirect_destdir!]
		goto :DONE
	)
	
	if /i "!bat_redirect_destdir:~-1,1!" equ "\" (
		
		!bat_echolog! EXITING RedirectLogs.bat EARLY - invalid dest path...[!bat_redirect_destdir!]
		goto :DONE
	)

		Rem We sometimes found that the first character of the destination dir
		rem was an underscore or a dir starting with one. 
	if /i "!bat_redirect_destdir:~0,1!" equ "_" (
		rem If the first character is "_", then bad parameters were given. In that
		rem case, it will default to the "..\Logs" dir for safe keeping. 
		rem Likewise, if there are no arguments, then it will default to 
		rem the "..\Logs" dir

		!bat_echolog! EXITING RedirectLogs.bat EARLY - invalid dest path...[!bat_logdir!]
		goto :DONE
	)

	if /i "!bat_redirect_destdir!" equ "" (
		rem Called without the dest dir

		!bat_echolog! EXITING RedirectLogs.bat EARLY - invalid dest path...[!bat_logdir!]
		goto :DONE

	) else (
		if /i "%~2" equ "" (
			!bat_echolog! EXITING RedirectLogs.bat EARLY  [%~f0] - Destination log directory not specified
			goto :DONE
		)
	)

		rem Usually, if a double-backslash is found in a path, it means that one of the variables
		rem used for an intermediate dir is blank,. 
	echo.!bat_redirect_sourcedir!|find /i "\\"
	if !errorlevel! equ 0 (
		!bat_echolog! `    ERROR - double-backslash - %~nx0 [%*]
		!bat_echolog! `             %~dpnx0 %* [bat_logdir=!bat_logdir!] [bat_redirect_sourcedir=!bat_redirect_sourcedir!]
		goto :DONE
	)
	
	if /i "!bat_redirect_sourcedir:~-1!" equ "\" (
		!bat_echolog! `    ERROR - trailing-backslash not allowed - %~nx0 [%*]
		!bat_echolog! `    %~dpnx0 %* [bat_logdir=!bat_logdir!] [bat_redirect_sourcedir=!bat_redirect_sourcedir!]
		goto :DONE
	)
	
goto :MAIN



		
:MAIN
!bat_pushlog! [GOTO !bat_batchfile!:MAIN] %*



	!bat_log! Redirecting logs settings to: !bat_redirect_destdir!
	!bat_log!
	!bat_pushlog! Before moving, Source dir:
		!bat_logexeclog! DIR "!bat_redirect_sourcedir!" /b /a-d
	!bat_poplog!
	
	!bat_pushlog! Before moving, Destination dir: 
		!bat_logexeclog! DIR "!bat_redirect_destdir!" /b /a-d
	!bat_poplog!

	if not exist "!bat_redirect_destdir!" (
			!bat_logexeclog! MD "!bat_redirect_destdir!"
	)


	call :LOGDIR_TO_REDIRECT

	call :LOOP_BASE
	
	call :LOOP_SOURCE

	CALL :REDIRECT_TO_LOGDIR

	set bat_redirect=&	rem delete the temporary variable

	!bat_log! After redirecting, the Current bat_logdir=!bat_logdir!
	!bat_log! After redirecting, the Current bat_logfile=!bat_logfile!
	!bat_log! After redirecting, the Current bat_logfile_full=!bat_logfile_full!
		
:MAIN_END
!bat_poplog! [RETURN !bat_batchfile!:MAIN] [bat_logdir=!bat_logdir!, 
!bat_log! `                                bat_logfile=!bat_logfile!, 
!bat_log! `                                bat_logfile_full=!bat_logfile_full!]
!bat_log!
goto :DONE


	rem ****************************************************************
	rem Temporarily redirecting any NEW log entries
	rem to C:\CAMS\Logs\Redirect
	rem
	rem They will be merged to the other logs after
	rem the main redirect is complete.
	rem 
	rem After this routine, it will be safe to use the bat_log 
	rem macros while the log files are moving
	rem
	rem ****************************************************************

:LOGDIR_TO_REDIRECT
!bat_pushlog! [CALL !bat_batchfile!:LOGDIR_TO_REDIRECT] %*

	CALL :CLEAN_REDIRECT
	
	!bat_log! Temporarily setting the logs to C:\Logs\Redirect
	!bat_log!
	
	set bat_logdir=!bat_redirect_base!\Redirect!
	set bat_logfile=!bat_logdir!\!bat_logfile_name!
	set bat_logfile_full=!bat_logdir!\AutoCams_full.log
	
	!bat_log! Temporarily setting the logs to C:\Logs\Redirect
	!bat_log!

:LOGDIR_TO_REDIRECT_END
!bat_poplog! [RETURN !bat_batchfile!:LOGDIR_TO_REDIRECT] [bat_logdir=!bat_logdir!, 
!bat_log! `                                bat_logfile=!bat_logfile!, 
!bat_log! `                                bat_logfile_full=!bat_logfile_full!]
!bat_log!
!BAT_RETURN!






:REDIRECT_TO_LOGDIR
!bat_pushlog! [CALL !bat_batchfile!:REDIRECT_TO_LOGDIR] %*

	set bat_redirect_sourcedir=!bat_redirect_base!\Redirect

	!bat_log! Changing back to bat_logdir=!bat_logdir!
	!bat_log!

	set bat_logdir=!bat_redirect_destdir!
	set bat_logfile=!bat_logdir!\!bat_logfile_name!
	set bat_logfile_full=!bat_logdir!\AutoCams_full.log

	!bat_log! Changing back to bat_logdir=!bat_logdir!
	!bat_log!


	call :LOOP_BASE

	call :LOOP_SOURCE

:REDIRECT_TO_LOGDIR_END
!bat_poplog! [RETURN !bat_batchfile!:REDIRECT_TO_LOGDIR] [bat_logdir=!bat_logdir!, 
!bat_log! `                                bat_logfile=!bat_logfile!, 
!bat_log! `                                bat_logfile_full=!bat_logfile_full!]
!bat_log!
!BAT_RETURN!







:CLEAN_REDIRECT
!bat_pushlog! [CALL !bat_batchfile!:CLEAN_REDIRECT] %*

	if exist "!bat_redirect_base!\Redirect!" (
		if defined bat_redirect_base (
			!bat_logexeclog! DEL /Q /F /S "!bat_redirect_base!\Redirect!"
			
			!bat_logexeclog! RD /Q /S "!bat_redirect_base!\Redirect!"
		)
	)
	
	!bat_logexeclog! MD "!bat_redirect_base!\Redirect!"

:CLEAN_REDIRECT_END
!bat_poplog! [RETURN !bat_batchfile!:CLEAN_REDIRECT] ["!bat_redirect_base!\Redirect!"]
!bat_log!
!BAT_RETURN!



	REM *************************************************************
	rem *******                LOOP_BASE                     ********
	REM
	REM Requires:
	rem   bat_redirect_base
	rem   bat_redirect_sourcedir
	rem   bat_redirect_destdir
	REM
	
:LOOP_BASE
!bat_pushlog! [CALL !bat_batchfile!:LOOP_BASE] %*


			rem call :CHECK_DIR_EMPTY "!bat_redirect_base!"
			dir "!bat_redirect_base!" | FINDSTR /L c:" 0 File(s)">nul: 2>&1
			if  "!errorlevel!" neq "0" (
				!bat_log!
				!bat_logexeclog! DIR "!bat_redirect_base!\*.*" /b /a-d /on
				!bat_log!

				rem  non-empty directory if you get here.
				
					rem In this case, move/merge all the files from the "CAMS\Logs" directory to the 
					rem source directory and then move everythign to the destination dir in the
					rem next loop
					rem
					rem So, the MAIN PURPOSE OF THIS FIRST LOOP is to merge logs from C:\CAMS\Logs to 
					rem the source dir. 
					rem

				!bat_log! for /f "usebackq tokens=*" ..X in ^(`dir "!bat_redirect_base!\*.*" /b /a-d /on `^) do ^(
				!bat_push!
				for           /f "usebackq tokens=*" %%X in  (`dir "!bat_redirect_base!\*.*" /b /a-d /on `) do (
					!bat_log!
					!bat_log! %%X		!bat_redirect_base!\%%X
					!bat_log!
REM *********

					CALL :MIGRATE_BASE_TO_SOURCE "%%X"


REM ****************
				)&	rem end of: for...
				!bat_pop! ^)

			) else (
				rem  empty directory
				!bat_log! OK - No files exist: "!bat_redirect_base!\*.*"
			)


:LOOP_BASE_END
!bat_poplog! [RETURN !bat_batchfile!:LOOP_BASE] [bat_redirect_destdir=!bat_redirect_destdir!, 
!bat_log! `                                bat_redirect_sourcedir=!bat_redirect_sourcedir!, 
!bat_log! `                                bat_redirect_destdir=!bat_redirect_destdir!]
!bat_log!
!bat_return!




	REM
	REM returns: bat_returncode
	rem             0       = means TRUE the directory was empty
	rem             1       = directory was not empty
	rem
	
:CHECK_DIR_EMPTY [IN] "dir"

	rem (dir *.* /b /a-d | findstr "." >nul 2>&1) && (echo not empty) || (echo empty)
	
	(dir "%~1\*.*" /b /a-d | findstr "." >nul: 2>&1 ) && (
		set bat_returncode=1&	rem NOT EMPTY
	) || (
		set bat_returncode=0&	REM EMPTY
	)

:CHECK_DIR_EMPTY_END [bat_returncode=!bat_returncode!; ]
!bat_return!






:LOOP_SOURCE
!bat_pushlog! [CALL !bat_batchfile!:LOOP_SOURCE] %*

		rem Now that the files have been normalized to the source dir, it's time to merge those
		rem to the dest dir.
		rem
					
	if /i "!bat_redirect_sourcedir!" neq "!bat_redirect_destdir!" (
		!bat_push!
			!bat_log!
			!bat_log! [b] Moving/Merging "!bat_redirect_sourcedir!\*.*" to the new log dir [!bat_redirect_destdir!]... 
			!bat_log!

				rem Only do this if the directory is not empty
			dir "!bat_redirect_base!" | FINDSTR /L c:" 0 File(s)">nul: 2>&1
			if  "!errorlevel!" neq "0" (
				
				!bat_log!
				!bat_logexeclog! DIR "!bat_redirect_sourcedir!\*.*" /a-d /b /on

				rem  non-empty directory

				for /f "usebackq tokens=*" %%X in (`dir "!bat_redirect_sourcedir!\*.*" /b /a-d /on `) do (

					!bat_log!
					!bat_log! !bat_redirect_sourcedir!\%%X
					!bat_log!
REM *********

					CALL :MIGRATE_SOURCE_TO_DEST "%%X"

REM *********
				)&	REM END OF: for /f "usebackq tokens=*" %%X in 
			) else (
				rem  empty directory
				!bat_log! No files exist: "!bat_redirect_sourcedir!\*.*"
			)&	REM END OF: if exist "!bat_redirect_sourcedir!\*.*"
			
			if /i "!bat_redirect_sourcedir!" neq "!bat_redirect_base!" (
				!bat_logexeclog! RD /q "!bat_redirect_sourcedir!"
		   	    !bat_log! bat_errorlevel=!bat_logexec_returncode!
			)
			
		!bat_pop!
	)&	REM END OF: if /i "!bat_redirect_sourcedir!" neq "!bat_redirect_destdir!"



:LOOP_SOURCE_END
!bat_poplog! [RETURN !bat_batchfile!:LOOP_SOURCE] [bat_redirect_destdir=!bat_redirect_destdir!, 
!bat_log! `                                bat_redirect_sourcedir=!bat_redirect_sourcedir!, 
!bat_log! `                                bat_redirect_destdir=!bat_redirect_destdir!]
!bat_log!
!bat_return!





	REM *************************************************************
	rem *******        MIGRATE_BASE_TO_SOURCE                ********
	REM
	REM Requires:
	rem   bat_redirect_base
	rem   bat_redirect_sourcedir
	rem   bat_redirect_destdir
	REM
	
:MIGRATE_BASE_TO_SOURCE
!bat_pushlog! [CALL !bat_batchfile!:MIGRATE_BASE_TO_SOURCE] %*


REM *********
						rem If the target file already exists, so append to the one in "!bat_redirect_sourcedir!"
					if exist "!bat_redirect_sourcedir!\%~1" (
					
						!bat_log! target file already exists, so append to the one in "!bat_redirect_sourcedir!"
					
							rem If the source and dest are NOT the same dir then MERGE, otherwise skip
						if /i "!bat_redirect_base!\%~1" neq "!bat_redirect_sourcedir!\%~1" (
							!bat_log!
							!bat_logexeclog! COPY /y "!bat_redirect_sourcedir!\%~1" + "!bat_redirect_base!\%~1" "!bat_redirect_sourcedir!\%~1.temp"
						                     !bat_log! bat_errorlevel=!bat_logexec_returncode!

							!bat_logexeclog! MOVE /y "!bat_redirect_sourcedir!\%~1.temp" "!bat_redirect_sourcedir!\%~1"
						               !bat_log! bat_errorlevel=!bat_logexec_returncode!


								rem Cleanup the original after the merge
							if exist "!bat_redirect_base!\%~1" (
								if /i "%~1" neq "" (
									!bat_logexeclog! DEL /q "!bat_redirect_base!\%~1"
						               !bat_log! bat_errorlevel=!bat_logexec_returncode!

								) else (
									!bat_log! `    ERROR [%~f0] Dangerous command: DEL /q "!bat_redirect_base!\%~1
								)
							) else (
								!bat_log! `    ERROR [%~f0] Dangerous command: DEL /q "!bat_redirect_base!\%~1

							)&	rem end of if exist "!bat_redirect_base!\%~1" 
						)&	rem end of if /i "!bat_redirect_base!\%~1" neq "!bat_redirect_sourcedir!\%~1"
					) else (

						!bat_log! target file does NOT already exists, so append it with this one...

						!bat_logexeclog! MOVE /y "!bat_redirect_base!\%~1" "!bat_redirect_sourcedir!"
						               !bat_log! bat_errorlevel=!bat_logexec_returncode!
						!bat_log! Note: The [MOVE /y "!bat_redirect_base!\*.*" "!bat_redirect_sourcedir!"] header is missing due to logfile change
					)&	rem end of: if exist "!bat_redirect_sourcedir!\%~1" 

REM ****************




:MIGRATE_BASE_TO_SOURCE_END
!bat_poplog! [RETURN !bat_batchfile!:MIGRATE_BASE_TO_SOURCE] [bat_redirect_destdir=!bat_redirect_destdir!, 
!bat_log! `                                bat_redirect_sourcedir=!bat_redirect_sourcedir!, 
!bat_log! `                                bat_redirect_destdir=!bat_redirect_destdir!]
!bat_log!
!bat_return!




:MIGRATE_SOURCE_TO_DEST
!bat_pushlog! [CALL !bat_batchfile!:MIGRATE_SOURCE_TO_DEST] %*



REM *******
						rem If the target file already exists, append/merge it....
					if exist "!bat_redirect_destdir!\%~1" (
					
						!bat_log! target file already exists, so append to the one in "!bat_redirect_destdir!"
					
						if /i "!bat_redirect_sourcedir!\%~1" neq "!bat_redirect_destdir!\%~1" (
							!bat_logexeclog! COPY /y "!bat_redirect_sourcedir!\%~1"  + "!bat_redirect_destdir!\%~1" "!bat_redirect_destdir!\%~1.temp"
						               !bat_log! bat_errorlevel=!bat_logexec_returncode!

							!bat_logexeclog! MOVE /y "!bat_redirect_destdir!\%~1.temp" "!bat_redirect_destdir!\%~1"
						               !bat_log! bat_errorlevel=!bat_logexec_returncode!


							if defined bat_redirect_sourcedir (
								if /i "%~1" neq "" (
									!bat_logexeclog! DEL /q "!bat_redirect_sourcedir!\%~1"
						               !bat_log! bat_errorlevel=!bat_logexec_returncode!
								) else (
									!bat_log! `    ERROR [%~f0] Dangerous command: del /q "!bat_redirect_sourcedir!\%~1"
								)
							) else (
								!bat_log! `    ERROR [%~f0] Dangerous command: del /q "!bat_redirect_sourcedir!\%~1"
							)&	REM END OF: if defined bat_redirect_sourcedir 
						)&	REM END OF: if /i "!bat_redirect_sourcedir!\%~1" neq "!bat_redirect_destdir!\%~1"
					) else (
						!bat_log!
						!bat_log! The target directory is empty, so we only need to move it without merging...
						!bat_log!
						!bat_logexeclog! MOVE /y "!bat_redirect_sourcedir!\%~1" "!bat_redirect_destdir!"
						               !bat_log! bat_errorlevel=!bat_logexec_returncode!


						!bat_log! Note: The [move /y "!bat_redirect_sourcedir!\*.*" "!bat_logdir!"] header is missing due to logfile change

					)&	REM END OF: if exist "!bat_redirect_destdir!\%~1"

REM *********


:MIGRATE_SOURCE_TO_DEST_END
!bat_poplog! [RETURN !bat_batchfile!:MIGRATE_SOURCE_TO_DEST] [bat_redirect_destdir=!bat_redirect_destdir!, 
!bat_log! `                                bat_redirect_sourcedir=!bat_redirect_sourcedir!, 
!bat_log! `                                bat_redirect_destdir=!bat_redirect_destdir!]
!bat_log!
!bat_return!


goto :DONE





:HELP
	@echo.%~0
	@echo.
	@echo.Usage: %~0 "<source dir>" "<new log dest dir>"
	@echo.
	@echo.Both directory specifications are requried. 
	@echo.
	@echo.However, there is one use-case where it is allow.  Let's say
	@echo.that you simply want to set the log directory without migrating
	@echo.existing logs [wherever they make be] without tying them
	@echo.to a capture session.  Therefore, 
	@echo.you would call it with only the dest dir as the only
	@echo.command lien option.
	@echo.
	@echo.Example:
	@echo.   %~0 "C:\CAMS\Logs" "C:\CAMS\Logs" 
	@echo.   %~0 "C:\CAMS\Logs" "C:\CAMS\Logs\2013_03_17_02_51_48"
	@echo.   %~0 "C:\CAMS\Logs\2013_03_17_02_51_48" "C:\CAMS\SubmissionFiles\2013_03_17_0213_02_51_48\213\Logs\2013_03_17_02_51_48"
	@echo.   %~0 "C:\CAMS\SubmissionFiles\2013_03_17_0213_02_51_48\213\Logs\2013_03_17_02_51_48"   "C:\CAMS\Logs\2013_03_17_02_51_48"
	@echo.
	@echo.Sets the future log destination to the "<new log dest dir>" and moves and merges the
	@echo.existing logs from "C:\CAMS\Logs" and "<source dir>" with the new logs in the new
	@echo.destination directory.
	@echo.
	@echo.Note: The C:\CAMS\Logs directory is only a temporary location for logs until there is a capture session.  
	@echo.
exit /b -99
	
:DONE
	!bat_poplog! [DONE:RedirectLogs.bat] [%*] [bat_logdir=!bat_logdir!]
	!bat_log! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

	set bat_pushstring=!bat_pushstring_save!
	set bat_pushstring_save=

	set bat_batchfile=!bat_batchfile_save!

	set bat_batchfile_save=
	
	set bat_errorlevel=
	
	set bat_redirect=
	set bat_redirect_base=
	set bat_redirect_sourcedir=
	set bat_redirect_destdir=
	set bat_redirect_currentdir=

	set bat_logfile_name=!bat_logfile_name_save!
	set bat_logfile_name_save=

exit /b 0

rem Test like this:
rem    cls&clear_bat_vars.bat&testscript call RedirectLogs.bat "C:\cam213\CAMS\Logs\2014_12_20_01_31_06" "c:\cam213\CAMS\SubmissionFiles\2014_12_20_266_01_31_06\266\Logs\2014_12_20_01_31_06"
