
	rem ****************************************************************************
	rem ******                LOGEXECLOG                               *************
	rem 
	rem This routine logs [without displaying] the output of a command by running it
	rem within a loop and then it displays the output indented to the current 
	rem bat_pushstring level. 
	rem
	rem The output of the command is differentiated from the log entries
	rem for this script by not displaying the date/time to the left of the
	rem output. 
	rem
	rem It's typically called using the autocams macro:
	rem    bat_logexeclog {command} 
	rem 
	rem This script is a subroutine that must be called from another script that 
	rem already has the following autocams.setup.bat and indent_setup.bat 
	rem variables defined.
	rem 
	rem This script is a subroutine that must be called from another script that 
	rem already has the following variables defined:
	rem   bat_log
	rem   bat_echolog
	rem   bat_push
	rem   bat_pop
	rem   bat_logdir


	rem This routine logs the output of a command by running it
	rem within a loop
:LOGEXEC 
	rem [out] !bat_logexec_returncode!

 		rem Indent and create a log entry with the time, batchfile that called this command,
 		rem and the whole command line.
	!bat_pushecho! [!bat_batchfile!:LOGEXEC] %*

		rem If the command string passed in is blank, then just output a blank line
		if /i "%~1" equ "" (
			!bat_echolog!
			set bat_logexec_returncode=0
			goto :LOGEXEC_END
		)

		set bat_logexeccommand=%*
		set bat_logexec_returncode=
		set bat_errorlevel=
		set bat_logexec_padding=                         

		set bat_logexec_teststr=!bat_logexeccommand:~0,1!
		if /i "!bat_logexec_teststr!" equ "`" (
			set bat_logexeccommand=!bat_logexeccommand:~1!
		)
		
		set bat_logexec_teststr=!bat_logexeccommand:~0,1!
		if /i "!bat_logexec_teststr!" equ "`" (set bat_logexeccommand=!bat_logexeccommand:~1!)

		if "!bat_logdir!" equ "" (
			rem echo.################### changing bat_logdir from "!bat_logdir!" to "!bat_exedir!\Logs"
			set bat_logdir=!bat_exedir!\Logs
		)

			rem The [`%*`] actuall executes the command.  The output
			rem from the command is queued into a buffer until the
			rem command is complete.  Then, the for loop echologs
			rem that output at the current indent level.


	rem Handling nested calls
	set /a bat_logexec_counter=0
:LOGEXEC2

		set bat_logexec_outfile=!bat_logdir!\indent_logexeclog.bat.!bat_logexec_counter!.log
		if exist "!bat_logexec_outfile!" (
			set /a bat_logexec_counter+=1
			goto :LOGEXEC2
		)

		rem When you get to here, you know you have a unique output file and avoid nesting issues. 
:LOGEXEC2_CONTINUE

			rem **********************************************************
			rem This section does the following:
			rem   - If the command string is a SET command, AND the command has an "=" sign,
			rem     then 
			rem     -  Execute the command string and then
			rem     -  Execute the command string to the left of the "=" to query the new value
			rem   - Otherwise, just execute the command string
			
			rem *****************************************************************
			rem ********** Execute the command string ***********
			rem
			rem The output from the command is I/O redirected to the bat_logexec_outfile
			rem file...

		!bat_logexeccommand!>"!bat_logexec_outfile!" 2>&1

		set bat_errorlevel=!errorlevel!
		set bat_logexec_returncode=!bat_errorlevel!
			rem *********************************************************

			rem Now output the command's results...

		if exist "!bat_logexec_outfile!" (
		
			if /i "!bat_logexeccommand:~0,4!" equ "SET " (
				rem If it's a SET command, then treat it a little differently

					rem If it's a set command, and because when you set a variable
					rem using the set command it doesn't output anything else, 
					rem then display the new value after setting it by entering 
					rem the left side of the "=" command.  For example:
					rem if the commandline was:
					rem 
					rem    "set junk=11111"
					rem 
					rem then the command line is executed, then this loop essentially 
					rem outputs this command: 
					rem 
					rem     set junk
					rem 
					rem You just need to remember that if there are other 
					rem variables that start with the same text as this variable
					rem it will also render the values for all that match. 
					rem 
					
				echo.!bat_logexeccommand!|find /i "=">nul 2>&1
				if !errorlevel! equ 0 (

						Rem This part is appending the output log with the
						rem additional entries.  For example, if the command
						rem was: set x=1, then this next loop collects the 
						rem result of the set assignment by doing this:
						rem set x
						rem which outputs: 
						rem   x=1
						rem without the SET portion of the command.

					for /f "tokens=1* delims==" %%W in ("!bat_logexeccommand!") do (
						%%W>>"!bat_logexec_outfile!" 2>&1
					)
				)
			)

				rem This section renders to the log the actual output of the command, 
				rem the SET values if it was a SET command...
				rem The "}" prefix to the string signals the log macro to display
				rem spaces instead of the [date time] column. This shows that it
				rem was direct output from a logexec command. 

			for /f "usebackq skip=2 tokens=1* delims=]" %%V in (`find /n /v "<" "!bat_logexec_outfile!"`) do (
				set bat_echolog_temp=%%W
				!bat_echolog! }!bat_echolog_temp!
			)

			if defined bat_logexec_outfile (
				DEL /Q  "!bat_logexec_outfile!" >nul: 2>&1
			) else (
				!bat_echolog! ERROR [!bat_batchfile!:LOGEXEC] Dangerous command:DEL /Q "!bat_logexec_outfile!"
			)
			
			set /a bat_logexec_counter-=1
			
		)

:LOGEXEC_END
!bat_popecho! [RETURN !bat_batchfile!:LOGEXEC] [errorlevel=bat_logexec_returncode=!bat_logexec_returncode!] [%*]
!bat_echolog!
	set bat_logexec_padding=
	set bat_logexeccommand=
	set bat_logexec_outfile=
	set bat_echolog_temp=
	set bat_logexec_counter=
exit /b !bat_logexec_returncode!



