
@echo off
setlocal enableextensions enabledelayedexpansion


rem ###########################################################################################
rem ###########################################################################################
rem ###################                                                    ####################
rem ###################      Thumbnails                                    ####################
rem ###################                                                    ####################
rem ###########################################################################################
rem ###########################################################################################



rem ===========================================================================================
rem                       :SETUP 
rem ===========================================================================================
rem   This section sets up initial variables, reads the INI file for site specific parameters,
rem   sets the log file variables, and displays the header.
rem ===========================================================================================

:SETUP
	rem --------------------- trigger the delayed expansion functionality
	for /f %%a in ("%~0") do (echo %%a)
	
	rem --------------------- Variable to be able to use %bat_return% to return from subroutines.
	set bat_return=goto :EOF

	rem --------------------- bat_exedir variable is where the rundir should be.
	set bat_exedir=%~dp0::
	set bat_exedir=!bat_exedir:\::=!
	set bat_exedir=!bat_exedir:::=!

	rem -------------------------------------------------------------------------------------------
	rem   Read the run parameters for processing at a given site
	rem 
	rem       First camera number of a 16 camera set with sequential/inclusive numbering
	rem       Number of independent detection processes to run during capture
	rem       Start and stop time is based on sun elevation angle in deg below local horizon
	rem       Number of FF files to skip for any given camera when doing star extraction
	rem       Number of stars to extract from each FF file
	rem       Number of CapturedFiles subfolders to retain before purging (deleting for space)
	rem       The CAMS directory full pathname up to and WITHOUT the \CAMS appended to the end
	rem
	rem   Note that "ReadParams_capture16.bat" reads the "capture16.params.ini" file to
	rem        retrieve all the variables for the above parameters. 
	rem -------------------------------------------------------------------------------------------
 
	echo.[!date:~4! !time!]  call "!bat_exedir!\ReadParams_capture16.bat">>"!bat_LogFile!"
	echo.[!date:~4! !time!]  call "!bat_exedir!\ReadParams_capture16.bat"
	                         call "!bat_exedir!\ReadParams_capture16.bat"


	rem --------------------- bat_LogFile is the target file for daily logging of processes run

	set bat_LogFile=!bat_CAMS_distrofolder!\DailyRunLog_!bat_firstcamera!.txt
	set bat_batchfile=%~nx0&	rem bat_batchfile is used for identifying which subroutine in the logs


	rem --------------------- Indicate the start of the script on the monitor and in the running log file 
	rem echo. bat_LogFile=!bat_LogFile!
	echo.>>"!bat_LogFile!"
	echo.>>"!bat_LogFile!"
    	echo.[!date:~4! !time!]  ================================================
    	echo.[!date:~4! !time!]  =================================================================================>>"!bat_LogFile!"
	echo.[!date:~4! !time!]  %~nx0 %*
	echo.[!date:~4! !time!]  BATCH %~nx0 %*>>"!bat_LogFile!"

	set bat_capturesession=%~1
	if /i "!bat_capturesession!" equ "" (
		echo. ### ERROR - no capture session directory provided ERROR ###>>"!bat_LogFile!"
		echo. ### ERROR - no capture session directory provided ERROR ###
		goto :HELP
	)
	
	set bat_decimation=%~2
	if /i "!bat_decimation!" equ "" (
		set bat_decimation=25
	)
	
	set bat_skip=%~3
	if /i "!bat_skip!" equ "" (
		set bat_skip=1
	)
	
	
	rem The fourth argument indicates that the thumbnail script should move the FF*.bin files
	rem back after creating the thumbnails.
	set bat_moveback=%~4
	
	if /i "!bat_FFprefix!" equ "" (
		echo.>>"!bat_LogFile!"
		echo.>>"!bat_LogFile!"
		echo.    ERROR - bat_FFprefix is blank>>"!bat_LogFile!"
		echo.>>"!bat_LogFile!"
		echo.>>"!bat_LogFile!"

		echo.
		echo.
		echo.    ERROR - bat_FFprefix is blank
		echo.
		echo.
		goto :DONE
		
	)

	set bat_capturedfiles_dir=!bat_CAMS_capturefolder!\!bat_capturesession!
	set bat_archivedfiles_dir=!bat_CAMS_archivefolder!\!bat_capturesession!
	set bat_thumbnails_dir=!bat_archivedfiles_dir!\!bat_capturesession!
	
	set bat_temp_file=!bat_thumbnails_dir!\temp.txt


goto :MAIN %*




rem ===============================================================================================
rem                                 :MAIN 
rem ===============================================================================================
rem   This is the main section of code that calls all the other processing subroutines in the
rem   following work flow order:
rem
rem      - Iterate through all the FTPdetectinfo_00??.txt files and scan for "FF7"
rem      - Move all the associated FF*.bin files to a subdir, labeled "..\thumbnails"
rem      - Run the FTP_Thumbnails.exe program
rem      - Move all the FF*.bin files back to their original CapturedFiles directory
rem      - Leave the thumbnails in the "..\thumbnails" dir until someone manually deletes them.
rem       
rem ===============================================================================================

:MAIN


	call :SCANDETECTFILES %*

			if !errorlevel! neq 0 ( goto :MAIN_END )

	call :MOVEFILES %*

			if !errorlevel! neq 0 ( goto :MAIN_END )


	call :THUMBNAILS %*

			if !errorlevel! neq 0 ( goto :MAIN_END )


	call :MOVEBACK %*

			if !errorlevel! neq 0 ( goto :MAIN_END )
goto :MAIN_END


:MAIN_END

	goto :DONE




Rem ===========================================================================================
Rem                         :SCANDETECTFILES
Rem ===========================================================================================
rem   Scan the FTPdetectinfo_00??.txt files for "FF7"
Rem ===========================================================================================

:SCANDETECTFILES

	echo.[!Date:~4! !Time!]      CALL   :!bat_batchfile!.SCANDETECTFILES %*>>"!bat_LogFile!"
	echo.[!Date:~4! !Time!]      CALL   :!bat_batchfile!.SCANDETECTFILES %*

    set bat_returncode=0


	if NOT EXIST "!bat_thumbnails_dir!" (
		echo.md "!bat_thumbnails_dir!">>"!bat_LogFile!"
		echo.md "!bat_thumbnails_dir!"
		     md "!bat_thumbnails_dir!"
	)

	if exist "!bat_temp_file!" (
		echo.del /q "!bat_temp_file!">>"!bat_LogFile!"
		echo.del /q "!bat_temp_file!"
		del /q "!bat_temp_file!"
	)
	
	set bat_detectfile=
	echo.>>"!bat_LogFile!"
	echo.
	echo.for /f "usebackq tokens=*" ..a in ^(`dir  "!bat_archivedfiles_dir!\!bat_detect_filespec!" /b][SORT /r`^) do ^(>>"!bat_LogFile!"
	echo.for /f "usebackq tokens=*" ..a in ^(`dir  "!bat_archivedfiles_dir!\!bat_detect_filespec!" /b][SORT /r`^) do ^(
	     for /f "usebackq tokens=*" %%a in  (`dir  "!bat_archivedfiles_dir!\!bat_detect_filespec!" /b^|SORT /r`) do (
		echo.%%a
		set bat_detectfile=%%a
	)
	echo.
	echo.bat_detectfile=!bat_detectfile!
	echo.

	if not defined bat_detectfile (
		echo.>>"!bat_LogFile!"
		echo.>>"!bat_LogFile!"
		echo.    ERROR - bat_detectfile not defined - no detect file found.>>"!bat_LogFile!"
		echo.>>"!bat_LogFile!"
		echo.>>"!bat_LogFile!"

		echo.
		echo.
		echo.    echo.    ERROR - bat_detectfile not defined - no detect file found.
		echo.
		echo.

		set bat_returncode=2
		goto :SCANDETECTFILES_END
	)

	set /a bat_count=0

	echo.for /f "usebackq tokens=*" ..a in ^(`find /i "!bat_FFprefix!" "!bat_archivedfiles_dir!\!bat_detectfile!"][SORT`^) do ^(>>"!bat_LogFile!"
	echo.for /f "usebackq tokens=*" ..a in ^(`find /i "!bat_FFprefix!" "!bat_archivedfiles_dir!\!bat_detectfile!"][SORT`^) do ^(
	     for /f "usebackq tokens=*" %%a in  (`find /i "!bat_FFprefix!" "!bat_archivedfiles_dir!\!bat_detectfile!"^|sort`) do (
		set bat_temp_line=%%a
		set bat_temp_FF=!bat_temp_line:~0,2!
		set bat_temp_camera=!bat_temp_line:~2,3!
		
		if /i "!bat_temp_FF!" equ "FF" (
			rem echo.[!bat_temp_line!]
			echo.!bat_temp_line!>>"!bat_temp_file!"
		)
	)



:SCANDETECTFILES_END

	echo.[!Date:~4! !Time!]      RETURN :!bat_batchfile!.SCANDETECTFILES         [exitcode=!bat_returncode!, bat_temp_file="!bat_temp_file!">>"!bat_LogFile!"
	echo.[!Date:~4! !Time!]      RETURN :!bat_batchfile!.SCANDETECTFILES         [exitcode=!bat_returncode!, bat_temp_file="!bat_temp_file!"
	exit /b !bat_returncode!





Rem ===========================================================================================
Rem                         :MOVEFILES
Rem ===========================================================================================
rem   Temporarily Move the FF*.bin files that have detections to a subdir.  The subdir will have 
rem   the same rem   name as the capture session.  Therefore, there will be two dirs with the 
rem   same name, one as subdir of the other. 
Rem ===========================================================================================

:MOVEFILES

	echo.[!Date:~4! !Time!]      CALL   :!bat_batchfile!.MOVEFILES %*>>"!bat_LogFile!"
	echo.[!Date:~4! !Time!]      CALL   :!bat_batchfile!.MOVEFILES %*

    set bat_returncode=0

	for /f "usebackq tokens=*" %%a in ("!bat_temp_file!") do (
		rem echo move /y "!bat_archivedfiles_dir!\%%a" "!bat_thumbnails_dir!"
		     move /y "!bat_archivedfiles_dir!\%%a" "!bat_thumbnails_dir!" 2>1>>"!bat_LogFile!"
	)


:MOVEFILES_END
	echo.[!Date:~4! !Time!]      RETURN :!bat_batchfile!.MOVEFILES         [exitcode=!bat_returncode!, bat_temp_file="!bat_temp_file!"]>>"!bat_LogFile!"
	echo.[!Date:~4! !Time!]      RETURN :!bat_batchfile!.MOVEFILES         [exitcode=!bat_returncode!, bat_temp_file="!bat_temp_file!"]
exit /b !bat_returncode!





Rem ===========================================================================================
Rem                         :THUMBNAILS
Rem ===========================================================================================
rem   Run the FTP_Thumbnails.exe program against the subset of FF*.bin files that were moved
rem   to the subdir.  It starts in /low process priority in case it's ever needed while
rem   capture is still happening. 
Rem ===========================================================================================

:THUMBNAILS

	echo.[!Date:~4! !Time!]      CALL   :!bat_batchfile!.THUMBNAILS %*>>"!bat_LogFile!"
	echo.[!Date:~4! !Time!]      CALL   :!bat_batchfile!.THUMBNAILS %*

    set bat_returncode=0
    
    echo. Launching FTP_Thumbnails.exe asynchronlously to build the thumbnails files...>>"!bat_LogFile!"
    echo. Launching FTP_Thumbnails.exe asynchronlously to build the thumbnails files...
    echo. start /w /low "FTP_Thumbnails.exe !bat_thumbnails_dir! !bat_decimation! !bat_skip!" "!bat_CAMS_runfolder!\FTP_Thumbnails.exe" "!bat_thumbnails_dir!"  !bat_decimation! !bat_skip!>>"!bat_LogFile!"
    echo. start /w /low "FTP_Thumbnails.exe !bat_thumbnails_dir! !bat_decimation! !bat_skip!" "!bat_CAMS_runfolder!\FTP_Thumbnails.exe" "!bat_thumbnails_dir!"  !bat_decimation! !bat_skip!
          start /w /low "FTP_Thumbnails.exe !bat_thumbnails_dir! !bat_decimation! !bat_skip!" "!bat_CAMS_runfolder!\FTP_Thumbnails.exe" "!bat_thumbnails_dir!"  !bat_decimation! !bat_skip!


    dir "!bat_thumbnails_dir!\*.bmp" /s/b

:THUMBNAILS_END
	echo.[!Date:~4! !Time!]      RETURN :!bat_batchfile!.THUMBNAILS         [exitcode=!bat_returncode!]>>"!bat_LogFile!"
	echo.[!Date:~4! !Time!]      RETURN :!bat_batchfile!.THUMBNAILS         [exitcode=!bat_returncode!]
	exit /b !bat_returncode!






Rem ===========================================================================================
Rem                         :MOVEBACK
Rem ===========================================================================================
rem   Move the temporarily moved subset of FF*.bin files back to the CapturedFiles dir.
Rem ===========================================================================================

:MOVEBACK

	echo.[!Date:~4! !Time!]      CALL   :!bat_batchfile!.MOVEBACK %*>>"!bat_LogFile!"
	echo.[!Date:~4! !Time!]      CALL   :!bat_batchfile!.MOVEBACK %*

    set bat_returncode=0

	if /i "!bat_moveback!" equ "moveBinFilesBack" (
		set bat_choice=m
		goto :MOVEBACK2
	)

:MOVEBACK1

	set bat_keep=
	set bat_choice=
	set /p bat_choice='[K]eep or [M]ove the files back? [M] 

	echo.[!bat_choice!]
	
	if /i "!bat_choice!" equ "" set bat_choice=m
	if /i "!bat_choice!" equ "k" (
		set bat_keep=true
		goto :MOVEBACK_END
	)
	
	if /i "!bat_choice!" neq "m" goto  :MOVEBACK1

:MOVEBACK2
	rem Start moving the files back.	
    	echo.move /y "!bat_thumbnails_dir!\*.bin" "!bat_archivedfiles_dir!"
             move /y "!bat_thumbnails_dir!\*.bin" "!bat_archivedfiles_dir!">>"!bat_LogFile!"

:MOVEBACK_END
	echo.[!Date:~4! !Time!]      RETURN :!bat_batchfile!.MOVEBACK         [exitcode=!bat_returncode!, bat_keep="!bat_keep!">>"!bat_LogFile!"
	echo.[!Date:~4! !Time!]      RETURN :!bat_batchfile!.MOVEBACK         [exitcode=!bat_returncode!, bat_keep="!bat_keep!"
	exit /b !bat_returncode!




Rem ===========================================================================================
Rem                         :CLEANUP
Rem ===========================================================================================
rem   Clean up the temporary directory.
Rem ===========================================================================================

:CLEANUP

	echo.[!Date:~4! !Time!]      CALL   :!bat_batchfile!.CLEANUP %*>>"!bat_LogFile!">>"!bat_LogFile!"
	echo.[!Date:~4! !Time!]      CALL   :!bat_batchfile!.CLEANUP %*>>"!bat_LogFile!"


:CLEANUP_END
	echo.[!Date:~4! !Time!]      RETURN :!bat_batchfile!.CLEANUP         [exitcode=!bat_returncode!, bat_temp_file="!bat_temp_file!">>"!bat_LogFile!"
	echo.[!Date:~4! !Time!]      RETURN :!bat_batchfile!.CLEANUP         [exitcode=!bat_returncode!, bat_temp_file="!bat_temp_file!"
	exit /b !bat_returncode!










:HELP
	echo.%~0	Batch Script
	echo.Usage: %~0 "<capture session>" [decimation [skip [FF file prefix]]] [moveBinFilesBack]
	echo.
	echo.This script iterates through the detections in the FTPdetectinfo_000?.txt files
	echo.that exist in the CapturedFiles dir.  It works like this:
	echo.   1^) It "moves" the associated files to the "..\CapturedFiles\<session>\thumbnails" 
	echo.      dir
	echo.   2^) It Runs the FTP_Thumbnails.exe program
	echo.   3^) It then moves all the FF*.bin files from the "..\thumbnails" dir back
	echo.      to the original CapturedFiles dir.
	echo.
	echo.The question remains, "Who is going to clean up the thumbnail .bmp files
	echo.after you're done using them?"
	echo.
	echo.Examples:
	echo.
	echo.  %~0 "2014_10_16_07_12_42"
	echo.
	echo. For weather check:
	echo.  %~0 "2014_10_16_07_12_42" 25 200
	echo.
	echo. For Fireball check [Creates 3k - 4k thumbnails for each camera]:
	echo.  %~0 "2014_10_16_07_12_42" 25 1
	echo.
	echo.  %~0 "2014_10_16_07_12_42" 25 200 FF7
	echo.Where "2014_10_16_07_12_42" is the capture session under the CapturedFiles directory.
	echo.
	echo.
exit /p 99




Rem ===========================================================================================
Rem    End of batch program
Rem ===========================================================================================

:DONE

	rem --------------- List the final state of all the variables
	rem SET BAT_
		echo.
		echo.[!date:~4! !time!]      :!bat_batchfile!.DONE                          [exitcode=!bat_returncode!]>>"!bat_LogFile!"
		echo.>>"!bat_LogFile!"
 
		echo.[!date:~4! !time!]      :!bat_batchfile!.DONE                          [exitcode=!bat_returncode!]
		echo.[!date:~4! !time!]~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		echo.

	rem --------------- Set the return code so a calling program or script can get the errorlevel or return code. 
	rem                 This is the same as the return code from main() in a C program.
ping localhost>nul 2>1
	exit /b !bat_returncode!



Rem ############################################################################################################################
Rem ############################################################################################################################
Rem ############################################################################################################################
Rem ############################################################################################################################
Rem ############################################################################################################################

